Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FormatBytes ¶
func GetGoVersion ¶
func GetGoVersion() string
func GetVersion ¶
func GetVersion() string
GetVersion returns the application version set by the build process. If the binary is a dev build, then it returns a truncated version of the latest commit hash.
func GetWorkingDir ¶
func GetWorkingDir() string
func NewPointer ¶
func NewPointer[T any](v T) *T
Types ¶
type InputHistory ¶
type InputHistory struct {
// contains filtered or unexported fields
}
func NewCmdHistory ¶
func NewCmdHistory() *InputHistory
func (*InputHistory) Add ¶
func (h *InputHistory) Add(v string)
func (*InputHistory) Cycle ¶
func (h *InputHistory) Cycle(msg tea.KeyMsg) (string, bool)
Cycle moves either up or down through the history of commands that have been added. Returns a string containing the command text if it exists, and true if history cycles back to present.
func (InputHistory) GetLen ¶
func (h InputHistory) GetLen() int
func (InputHistory) ListHistory ¶
func (h InputHistory) ListHistory() []string
Click to show internal directories.
Click to hide internal directories.